@@ -35,8 +35,9 @@ class FileIterable:
         return next(self._status)
 
     def __del__(self):
-        if not self.closed:
+        if not self.closed and not isinstance(self._fileiter, StringIO):
             self._fileiter.close()
+            self.closed = True
 
 
 class ConfigParser(MutableMapping):
@@ -45,7 +46,7 @@ class ConfigParser(MutableMapping):
     comment = "#"
     base = "DEFAULTS"
     _is_header = re.compile(r"\s*\[\s*(?P<header>.*)\]\s*")
-    _is_entry = re.compile(r"(?P<key>.*)=(?P<value>.*)")
+    _is_entry = re.compile(r"(?P<key>.*?)=(?P<value>.*)")
 
     def __init__(self, config, literals):
         self._config = config
